==> prestashop_1.5.0.15.zip: prestashop/modules/statsregistrations/translations/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Account clienti';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_089c9061407fd978366e78b6ad1d0111'] = 'Visualizzare lo stato di registrazione del cliente';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'I visitatori che si sono fermati alla fase di registrazione:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_4e4f3af3fb18136b8eec4b77f25095ce'] = 'I visitatori che hanno effettuato un ordine direttamente dopo la registrazione:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Totale account dei clienti:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_998e4c5c80f27dec552e99dfed34889a'] = 'Esporta CSV';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guida';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Numero di account clienti creati';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a286f4eaef73a0b4f955c42b84472444'] = 'Il numero totale di account creati non è di per sé un\'informazione importante. Tuttavia, è interessante analizzare il numero creato nel tempo. Questo indica se le cose sono sulla strada giusta.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = 'Come agire sull\'evoluzione delle iscrizioni?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f123e4522d188fba4cbe1dc58034f95c'] = 'Se lasci che il tuo negozio vada avanti senza cambiare nulla, il numero di iscrizioni dei clienti dovrebbe rimanere stabile o diminuire leggermente.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f8426f15c536f4341dbeb4d806f76167'] = 'Un significativo aumento o diminuzione dimostra che vi è stato probabilmente un cambiamento nel tuo negozio; pertanto, è necessario identificarlo in modo da effettuare degli aggiustamenti laddove questa modifica faccia diminuire il numero di registrazioni, o invece proseguire se il risultato è positivo.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_48ad285c9749cc74821048c49aea6a50'] = 'Ecco un riassunto di ciò che può influenzare la creazione di account cliente:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_cd0d9770ca8ee818040fa3453fbaa1ae'] = 'Una campagna pubblicitaria può attrarre un numero maggiore di visitatori. Un aumento di account dei clienti che ne seguirà, che dipenderà dalla loro \"qualità\": le pubblicità ben mirate possono essere più efficaci di una pubblicità su larga scala.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_b2eceb617c0a86e0dbe5d844f0ec353e'] = 'Le promozioni, le vendite, o concorsi creano una maggiore attenzione e curiosità, non solo mantengono vivace il tuo negozio, ma ne aumentano il traffico. In questo modo, puoi spingere gli acquirenti impulsivi a fare il grande passo.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_52a6042899eefb32fcd219672c0c7179'] = 'Design e semplicità d\'uso sono più importanti che mai: una grafica complicata o difficile da seguire può allontanare i visitatori. Devi trovare il giusto equilibrio tra un design innovativo e lasciare che i visitatori si muovano facilmente. Anche una corretta ortografia e una grande chiarezza ispireranno maggiore fiducia nel tuo negozio.';

==> prestashop_1.5.3.1.zip: prestashop/modules/statsregistrations/translations/it.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{statsregistrations}prestashop>statsregistrations_75abad0b891bc086fd4837e81a8c488a'] = 'I visitatori che si sono fermati alla fase di registrazione:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a286f4eaef73a0b4f955c42b84472444'] = 'Il numero totale di account creati non è di per sé un\'informazione importante. Tuttavia, è interessante analizzare il numero creato nel tempo. Questo indica se le cose sono sulla strada giusta.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f123e4522d188fba4cbe1dc58034f95c'] = 'Se lasci che il tuo negozio vada avanti senza cambiare nulla, il numero di iscrizioni dei clienti dovrebbe rimanere stabile o diminuire leggermente.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_48ad285c9749cc74821048c49aea6a50'] = 'Ecco un riassunto di ciò che può influenzare la creazione di account cliente:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_cd0d9770ca8ee818040fa3453fbaa1ae'] = 'Una campagna pubblicitaria può attrarre un numero maggiore di visitatori. Un aumento di account dei clienti che ne seguirà, che dipenderà dalla loro \\"qualità\\": le pubblicità ben mirate possono essere più efficaci di una pubblicità su larga scala.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_8b15fc6468c919d299f9a601b61b95fc'] = 'Account clienti';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_6602bbeb2956c035fb4cb5e844a4861b'] = 'Guida';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_57a6f41a27c9baa5b402d30e97d4c1e8'] = 'Come agire sull\'evoluzione delle iscrizioni?';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_f8426f15c536f4341dbeb4d806f76167'] = 'Un significativo aumento o diminuzione dimostra che vi è stato probabilmente un cambiamento nel tuo negozio; pertanto, è necessario identificarlo in modo da effettuare degli aggiustamenti laddove questa modifica faccia diminuire il numero di registrazioni, o invece proseguire se il risultato è positivo.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_52a6042899eefb32fcd219672c0c7179'] = 'Design e semplicità d\'uso sono più importanti che mai: una grafica complicata o difficile da seguire può allontanare i visitatori. Devi trovare il giusto equilibrio tra un design innovativo e lasciare che i visitatori si muovano facilmente. Anche una corretta ortografia e una grande chiarezza ispireranno maggiore fiducia nel tuo negozio.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_089c9061407fd978366e78b6ad1d0111'] = 'Visualizzare lo stato di registrazione del cliente';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_4e4f3af3fb18136b8eec4b77f25095ce'] = 'I visitatori che hanno effettuato un ordine direttamente dopo la registrazione:';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_998e4c5c80f27dec552e99dfed34889a'] = 'Esporta CSV';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_fba0e64541196123bbf8e3737bf9287b'] = 'Numero di account clienti creati';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_b2eceb617c0a86e0dbe5d844f0ec353e'] = 'Le promozioni, le vendite, o concorsi creano una maggiore attenzione e curiosità, non solo mantengono vivace il tuo negozio, ma ne aumentano il traffico. In questo modo, puoi spingere gli acquirenti impulsivi a fare il grande passo.';
$_MODULE['<{statsregistrations}prestashop>statsregistrations_a751e9cc4ed4c7585ecc0d97781cb48a'] = 'Totale account dei clienti:';
